@@ -1,19 +1,7 @@
 /*
- *  Copyright (c) 2008 Boudewijn Rempt <boud@valdyas.org>
+ *  SPDX-FileCopyrightText: 2008 Boudewijn Rempt <boud@valdyas.org>
  *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
- *  (at your option) any later version.
- *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
- *
- *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+ *  SPDX-License-Identifier: GPL-2.0-or-later
  */
 #include "kis_brush_registry.h"
 
@@ -26,7 +14,7 @@
 
 #include <kis_debug.h>
 
-#include "kis_brush_server.h"
+#include "KoResourceServer.h"
 #include "kis_auto_brush_factory.h"
 #include "kis_text_brush_factory.h"
 #include "kis_predefined_brush_factory.h"
@@ -36,7 +24,6 @@ Q_GLOBAL_STATIC(KisBrushRegistry, s_instance)
 
 KisBrushRegistry::KisBrushRegistry()
 {
-    KisBrushServer::instance();
 }
 
 KisBrushRegistry::~KisBrushRegistry()
@@ -61,15 +48,19 @@ KisBrushRegistry* KisBrushRegistry::instance()
 }
 
 
-KisBrushSP KisBrushRegistry::createBrush(const QDomElement& element)
+KoResourceLoadResult KisBrushRegistry::createBrush(const QDomElement& element, KisResourcesInterfaceSP resourcesInterface)
 {
     QString brushType = element.attribute("type");
 
-    if (brushType.isEmpty()) return 0;
+    if (brushType.isEmpty()) {
+        return KoResourceSignature(ResourceType::Brushes, "", "unknown", "unknown");
+    }
 
-    KisBrushFactory* factory = get(brushType);
-    if (!factory) return 0;
+    KisBrushFactory *factory = get(brushType);
+    if (!factory) {
+        return KoResourceSignature(ResourceType::Brushes, "", "unknown", "unknown");
+    }
 
-    return factory->createBrush(element);
+    return factory->createBrush(element, resourcesInterface);
 }
 
