@@ -39,7 +39,7 @@
 
 #ifdef DEBUG_MERGER
 #define DEBUG_NODE_ACTION(message, type, leaf, rect)            \
-    qDebug() << message << type << ":" << leaf->node()->name() << rect
+    qDebug() << message << type << ":" << leaf->node()->name() << rect << "rendered:" << leaf->shouldBeRendered()
 #else
 #define DEBUG_NODE_ACTION(message, type, leaf, rect)
 #endif
@@ -311,9 +311,9 @@ void KisAsyncMerger::resetProjection() {
 }
 
 void KisAsyncMerger::setupProjection(KisProjectionLeafSP currentLeaf, const QRect& rect, bool useTempProjection) {
-    KisPaintDeviceSP parentOriginal = currentLeaf->parent()->original();
+    KisPaintDeviceSP parentOriginal = currentLeaf->parent()->lazyDestinationForSubtreeComposition();
 
-    if (parentOriginal != currentLeaf->projection()) {
+    if (parentOriginal) {
         if (useTempProjection) {
             if(!m_cachedPaintDevice)
                 m_cachedPaintDevice = new KisPaintDevice(parentOriginal->colorSpace());
