@@ -1,5 +1,6 @@
 /*
  *  SPDX-FileCopyrightText: 2010 Lukáš Tvrdý <lukast.dev@gmail.com>
+ *  SPDX-FileCopyrightText: 2022 L. E. Segovia <amy@amyspark.me>
  *
  *  SPDX-License-Identifier: GPL-2.0-or-later
  */
@@ -12,7 +13,7 @@
 #include <QScopedPointer>
 
 #include "kritaimage_export.h"
-#include "kis_mask_generator.h"
+#include "kis_base_mask_generator.h"
 
 class KisCubicCurve;
 class QDomElement;
@@ -20,6 +21,8 @@ class QDomDocument;
 
 class QPointF;
 
+template<typename V>
+struct FastRowProcessor;
 
 /**
  * This mask generator use softness/hardness defined by user curve
@@ -27,8 +30,6 @@ class QPointF;
  */
 class KRITAIMAGE_EXPORT KisCurveCircleMaskGenerator : public KisMaskGenerator
 {
-public:
-    struct FastRowProcessor;
 public:
 
     KisCurveCircleMaskGenerator(qreal radius, qreal ratio, qreal fh, qreal fv, int spikes,const KisCubicCurve& curve, bool antialiasEdges);
@@ -59,6 +60,8 @@ private:
 private:
     struct Private;
     const QScopedPointer<Private> d;
+
+    friend struct FastRowProcessor<KisCurveCircleMaskGenerator>;
 };
 
 #endif
