@@ -49,16 +49,6 @@ private:
     void initFillPainter();
 
 public:
-
-    /**
-     * Fill a rectangle with black transparent pixels (0, 0, 0, 0 for RGBA).
-     */
-    void eraseRect(qint32 x1, qint32 y1, qint32 w, qint32 h);
-    /**
-     * Overloaded version of the above function.
-     */
-    void eraseRect(const QRect& rc);
-
     /**
      * Fill current selection of KisPainter with a specified \p color.
      *
@@ -67,25 +57,40 @@ public:
      */
     void fillSelection(const QRect &rc, const KoColor &color);
 
-    /**
-     * Fill a rectangle with a certain color.
-     */
-    void fillRect(qint32 x, qint32 y, qint32 w, qint32 h, const KoColor& c);
-
-    /**
-     * Overloaded version of the above function.
-     */
-    void fillRect(const QRect& rc, const KoColor& c);
-
     /**
      * Fill a rectangle with a certain color and opacity.
      */
-    void fillRect(qint32 x, qint32 y, qint32 w, qint32 h, const KoColor& c, quint8 opacity);
+    void fillRect(qint32 x,
+                  qint32 y,
+                  qint32 w,
+                  qint32 h,
+                  const KoColor &c,
+                  quint8 opacity);
 
     /**
      * Overloaded version of the above function.
      */
-    void fillRect(const QRect& rc, const KoColor& c, quint8 opacity);
+    inline void fillRect(const QRect &rc, const KoColor &c, quint8 opacity)
+    {
+        fillRect(rc.x(), rc.y(), rc.width(), rc.height(), c, opacity);
+    }
+
+    /**
+     * Fill a rectangle with a certain color.
+     */
+    inline void
+    fillRect(qint32 x, qint32 y, qint32 w, qint32 h, const KoColor &c)
+    {
+        fillRect(x, y, w, h, c, OPACITY_OPAQUE_U8);
+    }
+
+    /**
+     * Overloaded version of the above function.
+     */
+    inline void fillRect(const QRect &rc, const KoColor &c)
+    {
+        fillRect(rc.x(), rc.y(), rc.width(), rc.height(), c, OPACITY_OPAQUE_U8);
+    }
 
     /**
      * Fill a rectangle with a certain pattern. The pattern is repeated if it does not fit the
@@ -111,6 +116,31 @@ public:
      */
     void fillRect(const QRect& rc, const KoPatternSP pattern, const QPoint &offset = QPoint());
 
+    /**
+     * Fill a rectangle with black transparent pixels (0, 0, 0, 0 for RGBA).
+     */
+    inline void eraseRect(qint32 x1, qint32 y1, qint32 w, qint32 h)
+    {
+        const KoColorSpace *cs = KoColorSpaceRegistry::instance()->rgb8();
+        KoColor c(Qt::black, cs);
+        fillRect(x1, y1, w, h, c, OPACITY_TRANSPARENT_U8);
+    }
+
+    /**
+     * Overloaded version of the above function.
+     */
+    inline void eraseRect(const QRect &rc)
+    {
+        const KoColorSpace *cs = KoColorSpaceRegistry::instance()->rgb8();
+        KoColor c(Qt::black, cs);
+        fillRect(rc.x(),
+                 rc.y(),
+                 rc.width(),
+                 rc.height(),
+                 c,
+                 OPACITY_TRANSPARENT_U8);
+    }
+
     /**
      * @brief fillRect
      * Fill a rectangle with a certain pattern. The pattern is repeated if it does not fit the
@@ -195,13 +225,37 @@ public:
      * Set the threshold for floodfill. The range is 0-255: 0 means the fill will only
      * fill parts that are the exact same color, 255 means anything will be filled
      */
-    void setFillThreshold(int threshold);
+    inline void setFillThreshold(int threshold)
+    {
+        m_threshold = threshold;
+    }
 
     /** Returns the fill threshold, see setFillThreshold for details */
     int fillThreshold() const {
         return m_threshold;
     }
 
+    /**
+     * Set the opacity spread for floodfill. The range is 0-100: 0% means that
+     * the fully opaque area only encompasses the pixels exactly equal to the
+     * seed point with the other pixels of the selected region being
+     * semi-transparent (depending on how similar they are to the seed pixel)
+     * up to the region boundary (given by the threshold value). 100 means that
+     * the fully opaque area will encompass all the pixels of the selected
+     * region up to the contour. Any value inbetween will make the fully opaque
+     * portion of the region vary in size, with semi-transparent pixels
+     * inbetween it and  the region boundary
+     */
+    void setOpacitySpread(int opacitySpread)
+    {
+        m_opacitySpread = opacitySpread;
+    }
+
+    /** Returns the fill opacity spread, see setOpacitySpread for details */
+    int opacitySpread() const {
+        return m_opacitySpread;
+    }
+
     bool useCompositioning() const {
         return m_useCompositioning;
     }
@@ -230,6 +284,16 @@ public:
         m_careForSelection = set;
     }
 
+    /** Sets if antiAlias should be applied to the selection */
+    void setAntiAlias(bool antiAlias) {
+        m_antiAlias = antiAlias;
+    }
+    
+    /** Get if antiAlias should be applied to the selection */
+    bool antiAlias() const {
+        return m_antiAlias;
+    }
+
     /** Sets the auto growth/shrinking radius */
     void setSizemod(int sizemod) {
         m_sizemod = sizemod;
@@ -237,7 +301,7 @@ public:
     
     /** Sets how much to auto-grow or shrink (if @p sizemod is negative) the selection
     flood before painting, this affects every fill operation except fillRect */
-    int sizemod() {
+    int sizemod() const {
         return m_sizemod;
     }
     
@@ -248,7 +312,7 @@ public:
     
     /** defines the feathering radius for selection flood operations, this affects every
     fill operation except fillRect */
-    uint feather() {
+    uint feather() const {
         return m_feather;
     }
 
@@ -258,20 +322,33 @@ public:
     }
 
     /** defines if the selection borders are treated as boundary in flood fill or not */
-    uint useSelectionAsBoundary() {
+    uint useSelectionAsBoundary() const {
         return m_useSelectionAsBoundary;
     }
 
-private:
+protected:
+    void setCurrentFillSelection(KisSelectionSP fillSelection)
+    {
+        m_fillSelection = fillSelection;
+    }
+
+    KisSelectionSP currentFillSelection() const
+    {
+        return m_fillSelection;
+    }
+
     // for floodfill
     void genericFillStart(int startX, int startY, KisPaintDeviceSP sourceDevice);
     void genericFillEnd(KisPaintDeviceSP filled);
 
+private:
     KisSelectionSP m_fillSelection;
 
     int m_feather;
     int m_sizemod;
+    bool m_antiAlias;
     int m_threshold;
+    int m_opacitySpread;
     int m_width, m_height;
     QRect m_rect;
     bool m_careForSelection;
@@ -279,48 +356,4 @@ private:
     bool m_useSelectionAsBoundary;
 };
 
-
-inline
-void KisFillPainter::fillRect(qint32 x, qint32 y, qint32 w, qint32 h, const KoColor& c)
-{
-    fillRect(x, y, w, h, c, OPACITY_OPAQUE_U8);
-}
-
-inline
-void KisFillPainter::fillRect(const QRect& rc, const KoColor& c)
-{
-    fillRect(rc.x(), rc.y(), rc.width(), rc.height(), c, OPACITY_OPAQUE_U8);
-}
-
-inline
-void KisFillPainter::eraseRect(qint32 x1, qint32 y1, qint32 w, qint32 h)
-{
-    const KoColorSpace * cs = KoColorSpaceRegistry::instance()->rgb8();
-    KoColor c(Qt::black, cs);
-    fillRect(x1, y1, w, h, c, OPACITY_TRANSPARENT_U8);
-}
-
-inline
-void KisFillPainter::eraseRect(const QRect& rc)
-{
-    const KoColorSpace * cs = KoColorSpaceRegistry::instance()->rgb8();
-    KoColor c(Qt::black, cs);
-    fillRect(rc.x(), rc.y(), rc.width(), rc.height(), c, OPACITY_TRANSPARENT_U8);
-}
-
-inline
-void KisFillPainter::fillRect(const QRect& rc, const KoColor& c, quint8 opacity)
-{
-    fillRect(rc.x(), rc.y(), rc.width(), rc.height(), c, opacity);
-}
-
-
-
-inline
-void KisFillPainter::setFillThreshold(int threshold)
-{
-    m_threshold = threshold;
-}
-
-
 #endif //KIS_FILL_PAINTER_H_
