@@ -11,6 +11,8 @@
 #include "kritaimage_export.h"
 #include "kis_types.h"
 
+#include <mutex>
+
 class QBitArray;
 class KisUndoAdapter;
 class KisPostExecutionUndoAdapter;
@@ -18,6 +20,7 @@ class KisPainter;
 class KUndo2MagicString;
 class KoCompositeOp;
 class KoColor;
+class KisRunnableStrokeJobData;
 
 /**
  * For classes that support indirect painting.
@@ -55,7 +58,8 @@ public:
      * Writes the temporary target into the paint device of the layer.
      * This action will lock the temporary target itself.
      */
-    virtual void mergeToLayer(KisNodeSP layer, KisPostExecutionUndoAdapter *undoAdapter, const KUndo2MagicString &transactionText, int timedID = -1);
+    void mergeToLayer(KisNodeSP layer, KUndo2Command *parentCommand, const KUndo2MagicString &transactionText, int timedID);
+    virtual void mergeToLayerThreaded(KisNodeSP layer, KUndo2Command *parentCommand, const KUndo2MagicString &transactionText, int timedID, QVector<KisRunnableStrokeJobData *> *jobs);
 
     KisPaintDeviceSP temporaryTarget() const;
 
@@ -76,26 +80,78 @@ public:
         const KisIndirectPaintingSupport *m_lock;
     };
 
-protected:
-    void mergeToLayerImpl(KisPaintDeviceSP dst, KisPostExecutionUndoAdapter *undoAdapter, const KUndo2MagicString &transactionText, int timedID = -1, bool cleanResources = true);
-    virtual void writeMergeData(KisPainter *painter, KisPaintDeviceSP src);
-    void lockTemporaryTargetForWrite() const;
+    /**
+     * A simple RAII-styled class to release the write lock for the
+     * final merge while the stroke is suspended.
+     */
+    struct FinalMergeSuspender {
+        FinalMergeSuspender(KisIndirectPaintingSupport *indirect);
+        ~FinalMergeSuspender();
 
+    private:
+        const KisIndirectPaintingSupport *m_lock;
+    };
+    using FinalMergeSuspenderSP = QSharedPointer<FinalMergeSuspender>;
+
+    /**
+     * When the stroke uses multithreaded final merge and supports
+     * suspension, then it should also suspend the final merge explicitly
+     * by requesting a special RAII object for the whole period of
+     * suspension.
+     */
+    FinalMergeSuspenderSP trySuspendFinalMerge();
+
+protected:
     /**
      * A guard object to lock the temporary target for write
      */
     struct WriteLocker {
-        WriteLocker(KisIndirectPaintingSupport *lock) : m_lock(lock) {
+        WriteLocker(KisIndirectPaintingSupport *lock)
+            : m_lock(lock),
+              m_locked(true)
+        {
             m_lock->lockTemporaryTargetForWrite();
         }
+
+        WriteLocker(KisIndirectPaintingSupport *lock, std::defer_lock_t)
+            : m_lock(lock),
+              m_locked(false)
+        {
+        }
+
         ~WriteLocker() {
+            if (m_locked) {
+                m_lock->unlockTemporaryTarget();
+            }
+        }
+
+        void unlock() {
+            KIS_SAFE_ASSERT_RECOVER_RETURN(m_locked);
             m_lock->unlockTemporaryTarget();
+            m_locked = false;
+        }
+
+        void relock() {
+            KIS_SAFE_ASSERT_RECOVER_RETURN(!m_locked);
+            m_lock->lockTemporaryTargetForWrite();
+            m_locked = true;
+        }
+
+        bool isLocked() {
+            return m_locked;
         }
 
     private:
         KisIndirectPaintingSupport *m_lock;
+        bool m_locked = false;
     };
 
+    using WriteLockerSP = QSharedPointer<WriteLocker>;
+
+    void mergeToLayerImpl(KisPaintDeviceSP dst, KUndo2Command *parentCommand, const KUndo2MagicString &transactionText, int timedID, bool cleanResources, WriteLockerSP sharedWriteLock, QVector<KisRunnableStrokeJobData *> *jobs);
+    virtual void writeMergeData(KisPainter *painter, KisPaintDeviceSP src, const QRect &rc);
+    void lockTemporaryTargetForWrite() const;
+
     QString temporaryCompositeOp() const;
     void releaseResources();
 
