@@ -12,7 +12,6 @@
 #include <QReadWriteLock>
 #include <QString>
 
-#include "DebugPigment.h"
 #include "KoColorSpaceFactory.h"
 #include "KoColorProfile.h"
 #include "kis_assert.h"
@@ -21,7 +20,6 @@
 struct KoColorProfileStorage::Private {
     QHash<QString, KoColorProfile * > profileMap;
     QHash<QByteArray, KoColorProfile * > profileUniqueIdMap;
-    QList<KoColorProfile *> duplicates;
     QHash<QString, QString> profileAlias;
     QReadWriteLock lock;
 
@@ -30,18 +28,10 @@ struct KoColorProfileStorage::Private {
     ~Private()
     {
         Q_FOREACH (KoColorProfile *p, profileMap) {
-            profileUniqueIdMap.remove(p->uniqueId());
             delete p;
         }
         profileMap.clear();
-        Q_FOREACH (KoColorProfile *p, profileUniqueIdMap) {
-            delete p;
-        }
         profileUniqueIdMap.clear();
-        Q_FOREACH(KoColorProfile *p, duplicates) {
-            delete p;
-        }
-        duplicates.clear();
     }
 };
 
@@ -61,11 +51,9 @@ void KoColorProfileStorage::addProfile(KoColorProfile *profile)
 
     if (profile->valid()) {
         d->profileMap[profile->name()] = profile;
-        if (d->profileUniqueIdMap.contains(profile->uniqueId())) {
-            warnPigment << "Duplicated profile" << profile->name() << profile->fileName() << d->profileUniqueIdMap[profile->uniqueId()]->fileName();
-            d->duplicates.append(d->profileUniqueIdMap[profile->uniqueId()]);
+        if (!d->profileUniqueIdMap.isEmpty()) {
+            d->profileUniqueIdMap.insert(profile->uniqueId(), profile);
         }
-        d->profileUniqueIdMap.insert(profile->uniqueId(), profile);
     }
 }
 
