@@ -90,12 +90,32 @@ bool KisImportExportErrorCannotWrite::operator==(KisImportExportErrorCannotWrite
 
 
 
-KisImportExportErrorCode::KisImportExportErrorCode() : errorFieldUsed(None), cannotRead(), cannotWrite() { }
+KisImportExportErrorCode::KisImportExportErrorCode()
+    : errorFieldUsed(None)
+    , cannotRead()
+    , cannotWrite()
+{ }
 
-KisImportExportErrorCode::KisImportExportErrorCode(ImportExportCodes::ErrorCodeID id) : errorFieldUsed(CodeId), codeId(id),  cannotRead(), cannotWrite() { }
+KisImportExportErrorCode::KisImportExportErrorCode(ImportExportCodes::ErrorCodeID id)
+    : errorFieldUsed(CodeId)
+    , codeId(id)
+    , cannotRead()
+    , cannotWrite()
+{ }
 
-KisImportExportErrorCode::KisImportExportErrorCode(KisImportExportErrorCannotRead error) : errorFieldUsed(CannotRead), cannotRead(error), cannotWrite() { }
-KisImportExportErrorCode::KisImportExportErrorCode(KisImportExportErrorCannotWrite error) : errorFieldUsed(CannotWrite), cannotRead(), cannotWrite(error) { }
+KisImportExportErrorCode::KisImportExportErrorCode(KisImportExportErrorCannotRead error)
+    : errorFieldUsed(CannotRead)
+    , codeId(ImportExportCodes::Failure)
+    , cannotRead(error)
+    , cannotWrite()
+{ }
+
+KisImportExportErrorCode::KisImportExportErrorCode(KisImportExportErrorCannotWrite error)
+    : errorFieldUsed(CannotWrite)
+    , codeId(ImportExportCodes::Failure)
+    , cannotRead()
+    , cannotWrite(error)
+{ }
 
 
 bool KisImportExportErrorCode::isOk() const
@@ -158,7 +178,8 @@ QString KisImportExportErrorCode::errorMessage() const
                 return i18n("Unknown error.");
             case ImportExportCodes::InternalError:
                 return internal;
-
+            case ImportExportCodes::Busy:
+                return i18n("Image is busy.");
             // OK
             case ImportExportCodes::OK:
                 return i18n("The action has been completed successfully.");
@@ -185,25 +206,3 @@ bool KisImportExportErrorCode::operator==(KisImportExportErrorCode errorCode)
     }
     return cannotWrite == errorCode.cannotWrite;
 }
-
-
-QDebug operator<<(QDebug d, const KisImportExportErrorCode& errorCode)
-{
-    switch(errorCode.errorFieldUsed) {
-    case KisImportExportErrorCode::None:
-            d << "None of the error fields is in use.";
-        break;
-    case KisImportExportErrorCode::CannotRead:
-            d << "Cannot read: " << errorCode.cannotRead.m_error;
-        break;
-    case KisImportExportErrorCode::CannotWrite:
-        d << "Cannot write: " << errorCode.cannotRead.m_error;
-        break;
-    case KisImportExportErrorCode::CodeId:
-        d << "Error code = " << errorCode.codeId;
-    }
-    d << " " << errorCode.errorMessage();
-    return d;
-}
-
-
