@@ -307,7 +307,9 @@ void KisPasteIntoActionFactory::run(KisViewManager *viewManager)
     KisImageSP image = viewManager->image();
     if (!image) return;
 
-    const KisPaintDevice *clipdev = KisClipboard::instance()->clipFromKritaLayers(image->bounds(),
+    if (!KisClipboard::instance()->hasLayers()) return;
+
+    KisPaintDeviceSP clipdev = KisClipboard::instance()->clipFromKritaLayers(image->bounds(),
                                                                             image->colorSpace()).data();
     KisPaintDeviceSP clip = new KisPaintDevice(*clipdev);
 
