@@ -45,7 +45,7 @@ public:
 
 private:
     class Private;
-    Private * const d;
+    Private * const d {nullptr};
 };
 
 #endif // KIS_ROTATE_CANVAS_ACTION_H
