@@ -1,23 +1,11 @@
 /*
- *  Copyright (c) 2018 Dmitry Kazakov <dimula73@gmail.com>
+ *  SPDX-FileCopyrightText: 2018 Dmitry Kazakov <dimula73@gmail.com>
  *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
- *  (at your option) any later version.
- *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
- *
- *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+ *  SPDX-License-Identifier: GPL-2.0-or-later
  */
 #include "KisFrameCacheStoreTest.h"
 
-#include <QTest>
+#include <simpletest.h>
 #include <testutil.h>
 
 #include <KoColor.h>
@@ -121,12 +109,10 @@ public:
         m_updateInfoBuilder.setEffectiveTextureSize(QSize(256 - 16, 256 - 16));
 
         connect(this, SIGNAL(sigCompleteRegenerationInternal(int)), SLOT(notifyFrameCompleted(int)));
-        connect(this, SIGNAL(sigCancelRegenerationInternal(int)), SLOT(notifyFrameCancelled(int)));
+        connect(this, SIGNAL(sigCancelRegenerationInternal(int, CancelReason)), SLOT(notifyFrameCancelled(int, CancelReason)));
     }
 
-    void frameCompletedCallback(int frame, const QRegion &requestedRegion) override {
-        ENTER_FUNCTION() << ppVar(frame);
-
+    void frameCompletedCallback(int frame, const KisRegion &requestedRegion) override {
         KisImageSP image = requestedImage();
         KIS_SAFE_ASSERT_RECOVER_NOOP(frame == image->animationInterface()->currentTime());
 
@@ -153,13 +139,13 @@ public:
         emit sigCompleteRegenerationInternal(frame);
     }
 
-    void frameCancelledCallback(int frame) override {
-        emit sigCancelRegenerationInternal(frame);
+    void frameCancelledCallback(int frame, CancelReason cancelReason) override {
+        emit sigCancelRegenerationInternal(frame, cancelReason);
     }
 
 Q_SIGNALS:
     void sigCompleteRegenerationInternal(int frame);
-    void sigCancelRegenerationInternal(int frame);
+    void sigCancelRegenerationInternal(int frame, CancelReason cancelReason);
 
 private:
     KisOpenGLUpdateInfoBuilder m_updateInfoBuilder;
@@ -192,6 +178,6 @@ void KisFrameCacheStoreTest::test()
 
 }
 
-QTEST_MAIN(KisFrameCacheStoreTest)
+SIMPLE_TEST_MAIN(KisFrameCacheStoreTest)
 
 #include "KisFrameCacheStoreTest.moc"
