@@ -1,24 +1,12 @@
 /*
- *  Copyright (c) 2008 Boudewijn Rempt boud@valdyas.org
+ *  SPDX-FileCopyrightText: 2008 Boudewijn Rempt boud @valdyas.org
  *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
- *  (at your option) any later version.
- *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
- *
- *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+ *  SPDX-License-Identifier: GPL-2.0-or-later
  */
 #ifndef _UTIL_H_
 #define _UTIL_H_
 
-#include <QTest>
+#include <simpletest.h>
 #include <QBitArray>
 
 #include <KisDocument.h>
@@ -50,6 +38,7 @@
 #include "kis_default_bounds.h"
 #include "kis_transform_mask_params_interface.h"
 #include "kis_shape_controller.h"
+#include <KisGlobalResourcesInterface.h>
 
 
 KisSelectionSP createPixelSelection(KisPaintDeviceSP paintDevice)
@@ -77,7 +66,7 @@ KisSelectionSP createVectorSelection(KisPaintDeviceSP paintDevice, KisImageWSP i
     path->normalize();
     KisShapeSelection* shapeSelection = new KisShapeSelection(shapeController, image, vectorSelection);
     shapeSelection->addShape(path);
-    vectorSelection->setShapeSelection(shapeSelection);
+    vectorSelection->convertToVectorSelectionNoUndo(shapeSelection);
 
     return vectorSelection;
 }
@@ -125,15 +114,12 @@ KisDocument* createCompleteDocument(bool shouldMaskToShapeLayer = false)
     cloneLayer1->setY(100);
 
     KisSelectionSP pixelSelection = createPixelSelection(paintLayer1->paintDevice());
-    KisFilterConfigurationSP kfc = KisFilterRegistry::instance()->get("pixelize")->defaultConfiguration();
+    KisFilterConfigurationSP kfc = KisFilterRegistry::instance()->get("pixelize")->defaultConfiguration(KisGlobalResourcesInterface::instance());
     Q_ASSERT(kfc);
-    KisAdjustmentLayerSP adjustmentLayer1 = new KisAdjustmentLayer(image, "adjustmentLayer1", kfc, pixelSelection);
-    kfc = 0; // kfc cannot be shared!
+    KisAdjustmentLayerSP adjustmentLayer1 = new KisAdjustmentLayer(image, "adjustmentLayer1", kfc->cloneWithResourcesSnapshot(), pixelSelection);
 
     KisSelectionSP vectorSelection = createVectorSelection(paintLayer2->paintDevice(), image, doc->shapeController());
-    kfc = KisFilterRegistry::instance()->get("pixelize")->defaultConfiguration();
-    KisAdjustmentLayerSP adjustmentLayer2 = new KisAdjustmentLayer(image, "adjustmentLayer2", kfc, vectorSelection);
-    kfc = 0; // kfc cannot be shared!
+    KisAdjustmentLayerSP adjustmentLayer2 = new KisAdjustmentLayer(image, "adjustmentLayer2", kfc->cloneWithResourcesSnapshot(), vectorSelection);
 
     image->addNode(paintLayer1);
     image->addNode(group1);
@@ -158,33 +144,29 @@ KisDocument* createCompleteDocument(bool shouldMaskToShapeLayer = false)
     image->addNode(shapeLayer, group1);
     image->addNode(adjustmentLayer2, group1);
 
-    KisFilterMaskSP filterMask1 = new KisFilterMask();
-    filterMask1->setName("filterMask1");
+    KisFilterMaskSP filterMask1 = new KisFilterMask(image, "filterMask1");
 
-    kfc = KisFilterRegistry::instance()->get("pixelize")->defaultConfiguration();
-    filterMask1->setFilter(kfc);
+    kfc = KisFilterRegistry::instance()->get("pixelize")->defaultConfiguration(KisGlobalResourcesInterface::instance());
+    filterMask1->setFilter(kfc->cloneWithResourcesSnapshot());
     kfc = 0; // kfc cannot be shared!
 
     filterMask1->setSelection(createPixelSelection(paintLayer1->paintDevice()));
     image->addNode(filterMask1, paintLayer1);
 
-    KisFilterMaskSP filterMask2 = new KisFilterMask();
-    filterMask2->setName("filterMask2");
+    KisFilterMaskSP filterMask2 = new KisFilterMask(image, "filterMask2");
 
-    kfc = KisFilterRegistry::instance()->get("pixelize")->defaultConfiguration();
-    filterMask2->setFilter(kfc);
+    kfc = KisFilterRegistry::instance()->get("pixelize")->defaultConfiguration(KisGlobalResourcesInterface::instance());
+    filterMask2->setFilter(kfc->cloneWithResourcesSnapshot());
     kfc = 0; // kfc cannot be shared!
 
     filterMask2->setSelection(createVectorSelection(paintLayer2->paintDevice(), image, doc->shapeController()));
     image->addNode(filterMask2, paintLayer2);
 
-    KisTransparencyMaskSP transparencyMask1 = new KisTransparencyMask();
-    transparencyMask1->setName("transparencyMask1");
+    KisTransparencyMaskSP transparencyMask1 = new KisTransparencyMask(image, "transparencyMask1");
     transparencyMask1->setSelection(createPixelSelection(paintLayer1->paintDevice()));
     image->addNode(transparencyMask1, group1);
 
-    KisTransparencyMaskSP transparencyMask2 = new KisTransparencyMask();
-    transparencyMask2->setName("transparencyMask2");
+    KisTransparencyMaskSP transparencyMask2 = new KisTransparencyMask(image, "transparencyMask2");
     transparencyMask2->setSelection(createPixelSelection(paintLayer1->paintDevice()));
     image->addNode(transparencyMask2, group2);
 
@@ -198,8 +180,7 @@ KisDocument* createCompleteDocument(bool shouldMaskToShapeLayer = false)
     selectionMask2->setSelection(createPixelSelection(paintLayer2->paintDevice()));
     image->addNode(selectionMask2, paintLayer2);
 
-    KisTransformMaskSP transformMask = new KisTransformMask();
-    transformMask->setName("testTransformMask");
+    KisTransformMaskSP transformMask = new KisTransformMask(image, "testTransformMask");
     transformMask->setTransformParams(KisTransformMaskParamsInterfaceSP(
                                           new KisDumbTransformMaskParams(createTestingTransform())));
 
@@ -207,8 +188,7 @@ KisDocument* createCompleteDocument(bool shouldMaskToShapeLayer = false)
 
     if (shouldMaskToShapeLayer) {
         // add all-visible transparency mask to crash a shape layer
-        KisTransparencyMaskSP transparencyMask3 = new KisTransparencyMask();
-        transparencyMask3->setName("crashy-transparency-mask");
+        KisTransparencyMaskSP transparencyMask3 = new KisTransparencyMask(image, "crashy-transparency-mask");
         transparencyMask3->initSelection(shapeLayer);
         image->addNode(transparencyMask3, shapeLayer);
     }
