@@ -1,19 +1,7 @@
 /*
- *  Copyright (c) 2005 Adrian Page <adrian@pagenet.plus.com>
+ *  SPDX-FileCopyrightText: 2005 Adrian Page <adrian@pagenet.plus.com>
  *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
- *  (at your option) any later version.
- *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
- *
- *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+ *  SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #include "kis_tool_shape.h"
@@ -68,9 +56,9 @@ KisToolShape::~KisToolShape()
     }
 }
 
-void KisToolShape::activate(ToolActivation toolActivation, const QSet<KoShape*> &shapes)
+void KisToolShape::activate(const QSet<KoShape*> &shapes)
 {
-    KisToolPaint::activate(toolActivation, shapes);
+    KisToolPaint::activate(shapes);
     m_configGroup =  KSharedConfig::openConfig()->group(toolId());
 }
 
@@ -87,12 +75,24 @@ QWidget * KisToolShape::createOptionWidget()
 
     m_shapeOptionsWidget->cmbOutline->setCurrentIndex(KisPainter::StrokeStyleBrush);
 
+    m_shapeOptionsWidget->angleSelectorRotation->setIncreasingDirection(KisAngleGauge::IncreasingDirection_Clockwise);
+    m_shapeOptionsWidget->angleSelectorRotation->setFlipOptionsMode(KisAngleSelector::FlipOptionsMode_MenuButton);
+
+    m_shapeOptionsWidget->sldScale->setSuffix("%");
+    m_shapeOptionsWidget->sldScale->setRange(0.0, 10000.0, 2);
+    m_shapeOptionsWidget->sldScale->setSoftMaximum(500);
+    m_shapeOptionsWidget->sldScale->setSingleStep(1.0);
+
     //connect two combo box event. Inherited classes can call the slots to make appropriate changes
     connect(m_shapeOptionsWidget->cmbOutline, SIGNAL(currentIndexChanged(int)), this, SLOT(outlineSettingChanged(int)));
     connect(m_shapeOptionsWidget->cmbFill, SIGNAL(currentIndexChanged(int)), this, SLOT(fillSettingChanged(int)));
+    connect(m_shapeOptionsWidget->angleSelectorRotation, SIGNAL(angleChanged(qreal)), this, SLOT(patternRotationSettingChanged(qreal)));
+    connect(m_shapeOptionsWidget->sldScale, SIGNAL(valueChanged(qreal)), this, SLOT(patternScaleSettingChanged(qreal)));
 
     m_shapeOptionsWidget->cmbOutline->setCurrentIndex(m_configGroup.readEntry("outlineType", 0));
     m_shapeOptionsWidget->cmbFill->setCurrentIndex(m_configGroup.readEntry("fillType", 0));
+    m_shapeOptionsWidget->sldScale->setValue(m_configGroup.readEntry("patternTransformScale", 100));
+    m_shapeOptionsWidget->angleSelectorRotation->setAngle(m_configGroup.readEntry("patternTransformRotation", 0));
 
     //if both settings are empty, force the outline to brush so the tool will work when first activated
     if (  m_shapeOptionsWidget->cmbFill->currentIndex() == 0 &&
@@ -101,6 +101,9 @@ QWidget * KisToolShape::createOptionWidget()
         m_shapeOptionsWidget->cmbOutline->setCurrentIndex(1); // brush
     }
 
+    bool enablePatternTransform = (m_shapeOptionsWidget->cmbFill->currentIndex() == int(KisToolShapeUtils::FillStylePattern));
+    m_shapeOptionsWidget->gbPatternTransform->setEnabled(enablePatternTransform);
+
     return m_shapeOptionsWidget;
 }
 
@@ -112,30 +115,55 @@ void KisToolShape::outlineSettingChanged(int value)
 void KisToolShape::fillSettingChanged(int value)
 {
     m_configGroup.writeEntry("fillType", value);
+    bool enable = (value == int(KisToolShapeUtils::FillStylePattern));
+    m_shapeOptionsWidget->gbPatternTransform->setEnabled(enable);
 }
 
-KisPainter::FillStyle KisToolShape::fillStyle(void)
+void KisToolShape::patternRotationSettingChanged(qreal value)
+{
+    m_configGroup.writeEntry("patternTransformRotation", value);
+}
+
+void KisToolShape::patternScaleSettingChanged(qreal value)
+{
+    m_configGroup.writeEntry("patternTransformScale", value);
+}
+
+KisToolShapeUtils::FillStyle KisToolShape::fillStyle()
 {
     if (m_shapeOptionsWidget) {
-        return static_cast<KisPainter::FillStyle>(m_shapeOptionsWidget->cmbFill->currentIndex());
+        return static_cast<KisToolShapeUtils::FillStyle>(m_shapeOptionsWidget->cmbFill->currentIndex());
     } else {
-        return KisPainter::FillStyleNone;
+        return KisToolShapeUtils::FillStyleNone;
     }
 }
 
-KisPainter::StrokeStyle KisToolShape::strokeStyle(void)
+KisToolShapeUtils::StrokeStyle KisToolShape::strokeStyle()
 {
     if (m_shapeOptionsWidget) {
-        return static_cast<KisPainter::StrokeStyle>(m_shapeOptionsWidget->cmbOutline->currentIndex());
+        return static_cast<KisToolShapeUtils::StrokeStyle>(m_shapeOptionsWidget->cmbOutline->currentIndex());
     } else {
-        return KisPainter::StrokeStyleNone;
+        return KisToolShapeUtils::StrokeStyleNone;
     }
 }
 
+QTransform KisToolShape::fillTransform()
+{
+    QTransform transform;
+
+    if (m_shapeOptionsWidget) {
+        transform.rotate(m_shapeOptionsWidget->angleSelectorRotation->angle());
+        qreal scale = m_shapeOptionsWidget->sldScale->value()*0.01;
+        transform.scale(scale, scale);
+    }
+
+    return transform;
+}
+
 qreal KisToolShape::currentStrokeWidth() const
 {
     const qreal sizeInPx =
-        canvas()->resourceManager()->resource(KisCanvasResourceProvider::Size).toReal();
+        canvas()->resourceManager()->resource(KoCanvasResource::Size).toReal();
 
     return canvas()->unit().fromUserValue(sizeInPx);
 }
@@ -165,48 +193,35 @@ void KisToolShape::ShapeAddInfo::markAsSelectionShapeIfNeeded(KoShape *shape) co
 
 void KisToolShape::addShape(KoShape* shape)
 {
-    KoImageCollection* imageCollection = canvas()->shapeController()->resourceManager()->imageCollection();
+    using namespace KisToolShapeUtils;
+
     switch(fillStyle()) {
-        case KisPainter::FillStyleForegroundColor:
+        case FillStyleForegroundColor:
             shape->setBackground(QSharedPointer<KoColorBackground>(new KoColorBackground(currentFgColor().toQColor())));
             break;
-        case KisPainter::FillStyleBackgroundColor:
+        case FillStyleBackgroundColor:
             shape->setBackground(QSharedPointer<KoColorBackground>(new KoColorBackground(currentBgColor().toQColor())));
             break;
-        case KisPainter::FillStylePattern:
-            if (imageCollection) {
-                QSharedPointer<KoPatternBackground> fill(new KoPatternBackground(imageCollection));
-                if (currentPattern()) {
-                    fill->setPattern(currentPattern()->pattern());
-                    shape->setBackground(fill);
-                }
-            } else {
-                shape->setBackground(QSharedPointer<KoShapeBackground>(0));
-            }
+        case FillStylePattern:
+            shape->setBackground(QSharedPointer<KoShapeBackground>(0));
             break;
-        case KisPainter::FillStyleGradient:
-            {
-                QLinearGradient *gradient = new QLinearGradient(QPointF(0, 0), QPointF(1, 1));
-                gradient->setCoordinateMode(QGradient::ObjectBoundingMode);
-                gradient->setStops(currentGradient()->toQGradient()->stops());
-                QSharedPointer<KoGradientBackground>  gradientFill(new KoGradientBackground(gradient));
-                shape->setBackground(gradientFill);
-            }
-            break;
-        case KisPainter::FillStyleNone:
-        default:
+        case FillStyleNone:
             shape->setBackground(QSharedPointer<KoShapeBackground>(0));
             break;
     }
 
     switch (strokeStyle()) {
-    case KisPainter::StrokeStyleNone:
+    case KisToolShapeUtils::StrokeStyleNone:
         shape->setStroke(KoShapeStrokeModelSP());
         break;
-    case KisPainter::StrokeStyleBrush: {
+    case KisToolShapeUtils::StrokeStyleForeground:
+    case KisToolShapeUtils::StrokeStyleBackground: {
         KoShapeStrokeSP stroke(new KoShapeStroke());
         stroke->setLineWidth(currentStrokeWidth());
-        stroke->setColor(canvas()->resourceManager()->foregroundColor().toQColor());
+        const QColor color = strokeStyle() == KisToolShapeUtils::StrokeStyleForeground ?
+                    canvas()->resourceManager()->foregroundColor().toQColor() :
+                    canvas()->resourceManager()->backgroundColor().toQColor();
+        stroke->setColor(color);
         shape->setStroke(stroke);
         break;
     }
@@ -247,7 +262,8 @@ void KisToolShape::addPathShape(KoPathShape* pathShape, const KUndo2MagicString&
                                            node,
                                            canvas()->resourceManager(),
                                            strokeStyle(),
-                                           fillStyle());
+                                           fillStyle(),
+                                           fillTransform());
         helper.paintPainterPath(mapedOutline);
     } else if (node->inherits("KisShapeLayer")) {
         pathShape->normalize();
