@@ -1,19 +1,7 @@
 /*
- *  Copyright (c) 2004 Cyrille Berger <cberger@cberger.net>
+ *  SPDX-FileCopyrightText: 2004 Cyrille Berger <cberger@cberger.net>
  *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
- *  (at your option) any later version.
- *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
- *
- *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+ *  SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #include "widgets/kis_multi_double_filter_widget.h"
@@ -26,9 +14,10 @@
 #include <kis_config_widget.h>
 #include <filter/kis_filter_configuration.h>
 #include <klocalizedstring.h>
+#include <KisGlobalResourcesInterface.h>
 
 KisDelayedActionDoubleInput::KisDelayedActionDoubleInput(QWidget * parent, const QString & name)
-    : KisDoubleParseSpinBox(parent)
+    : KisDoubleSliderSpinBox(parent)
 {
     setObjectName(name);
     m_timer = new QTimer(this);
@@ -113,7 +102,7 @@ void KisMultiDoubleFilterWidget::setConfiguration(const KisPropertiesConfigurati
 
 KisPropertiesConfigurationSP KisMultiDoubleFilterWidget::configuration() const
 {
-    KisFilterConfigurationSP config = new KisFilterConfiguration(m_filterid, 0);
+    KisFilterConfigurationSP config = new KisFilterConfiguration(m_filterid, 0, KisGlobalResourcesInterface::instance());
     for (int i = 0; i < nbValues(); ++i) {
         config->setProperty(m_doubleWidgets[i]->objectName(), m_doubleWidgets[i]->value());
     }
