@@ -2,20 +2,7 @@
  * Copyright 2010 (C) Boudewijn Rempt <boud@valdyas.org>
  * Copyright 2011 (C) Dmitry Kazakov <dimula73@gmail.com>
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
- *
- * You should have received a copy of the GNU Library General Public License
- * along with this library; see the file COPYING.LIB.  If not, write to
- * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
+ * SPDX-License-Identifier: LGPL-2.0-or-later
  */
 #include "kis_scratch_pad.h"
 
@@ -100,6 +87,25 @@ private:
     KisScratchPad *m_scratchPad;
 };
 
+class KisScratchPadPaintingInformationBuilder : public KisPaintingInformationBuilder
+{
+    Q_OBJECT
+
+public:
+    KisScratchPadPaintingInformationBuilder(KisScratchPad *scratchPad)
+        : m_scratchPad(scratchPad)
+    {
+    }
+
+protected:
+    QPointF imageToView(const QPointF &point) override {
+        return m_scratchPad->documentToWidget().map(point);
+    }
+
+private:
+    const KisScratchPad *m_scratchPad;
+};
+
 
 KisScratchPad::KisScratchPad(QWidget *parent)
     : QWidget(parent)
@@ -114,8 +120,8 @@ KisScratchPad::KisScratchPad(QWidget *parent)
     setAutoFillBackground(false);
     setMouseTracking(true);
 
-    m_cursor = KisCursor::load("tool_freehand_cursor.png", 5, 5);
-    m_colorPickerCursor = KisCursor::load("tool_color_picker_cursor.png", 5, 5);
+    m_cursor = KisCursor::load("tool_freehand_cursor.xpm", 2, 2);
+    m_colorSamplerCursor = KisCursor::load("tool_color_sampler_cursor.xpm", 2, 2);
     setCursor(m_cursor);
 
 
@@ -136,7 +142,7 @@ KisScratchPad::KisScratchPad(QWidget *parent)
     // filter will be deleted by the QObject hierarchy
     m_eventFilter = new KisScratchPadEventFilter(this);
 
-    m_infoBuilder = new KisPaintingInformationBuilder();
+    m_infoBuilder = new KisScratchPadPaintingInformationBuilder(this);
 
     m_scaleBorderWidth = 1;
 }
@@ -156,7 +162,7 @@ KisScratchPad::Mode KisScratchPad::modeFromButton(Qt::MouseButton button) const
     return
         button == Qt::NoButton ? HOVERING :
         button == Qt::MidButton ? PANNING :
-        button == Qt::RightButton ? PICKING :
+        button == Qt::RightButton ? SAMPLING :
         PAINTING;
 }
 
@@ -187,8 +193,8 @@ void KisScratchPad::pointerPress(KoPointerEvent *event)
             beginPan(event);
             event->accept();
         }
-        else if (m_toolMode == PICKING) {
-            pick(event);
+        else if (m_toolMode == SAMPLING) {
+            sample(event);
             event->accept();
         }
     }
@@ -213,7 +219,7 @@ void KisScratchPad::pointerRelease(KoPointerEvent *event)
             m_toolMode = HOVERING;
             event->accept();
         }
-        else if (m_toolMode == PICKING) {
+        else if (m_toolMode == SAMPLING) {
             event->accept();
             m_toolMode = HOVERING;
         }
@@ -250,8 +256,8 @@ void KisScratchPad::pointerMove(KoPointerEvent *event)
             doPan(event);
             event->accept();
         }
-        else if (m_toolMode == PICKING) {
-            pick(event);
+        else if (m_toolMode == SAMPLING) {
+            sample(event);
             event->accept();
         }
     }
@@ -310,10 +316,10 @@ void KisScratchPad::endPan(KoPointerEvent *event)
 
 }
 
-void KisScratchPad::pick(KoPointerEvent *event)
+void KisScratchPad::sample(KoPointerEvent *event)
 {
     KoColor color;
-    if (KisToolUtils::pickColor(color, m_paintLayer->projection(), event->point.toPoint())) {
+    if (KisToolUtils::sampleColor(color, m_paintLayer->projection(), event->point.toPoint())) {
         emit colorSelected(color);
     }
 }
@@ -391,7 +397,14 @@ void KisScratchPad::paintEvent ( QPaintEvent * event ) {
     QPainter gc(this);
     gc.fillRect(event->rect(), m_checkBrush);
 
-    gc.setRenderHints(QPainter::SmoothPixmapTransform);
+    // if we scale down, it should use Smooth
+    // if we scale up, it should use Fast (nearest Neighbour) to show pixels
+    if (event->rect().width() < image.rect().width()) {
+        gc.setRenderHints(QPainter::SmoothPixmapTransform);
+    } else {
+        gc.setRenderHints(0); // that will use NN
+    }
+
     gc.drawImage(QRectF(event->rect()), image, imageRect.translated(-offset));
 
     QBrush brush(Qt::lightGray);
@@ -468,9 +481,9 @@ void KisScratchPad::setModeType(QString mode)
         m_toolMode = PANNING;
         setCursor(Qt::OpenHandCursor);
     }
-    else if (mode.toLower() == "colorpicking") {
-        m_toolMode = PICKING;
-        setCursor(m_colorPickerCursor);
+    else if (mode.toLower() == "colorsampling") {
+        m_toolMode = SAMPLING;
+        setCursor(m_colorSamplerCursor);
     }
 }
 
@@ -624,7 +637,7 @@ void KisScratchPad::fillGradient()
     if(!m_paintLayer) return;
     KisPaintDeviceSP paintDevice = m_paintLayer->paintDevice();
 
-    KoAbstractGradient* gradient = m_resourceProvider->currentGradient();
+    KoAbstractGradientSP gradient = m_resourceProvider->currentGradient();
     QRect gradientRect = widgetToDocument().mapRect(rect());
 
     KisTransaction t(paintDevice);
@@ -670,3 +683,5 @@ void KisScratchPad::fillLayer()
     painter.deleteTransaction();
     update();
 }
+
+#include "kis_scratch_pad.moc"
