@@ -1,21 +1,9 @@
 /*
- * Copyright (c) 2008 Cyrille Berger <cberger@cberger.net>
- * Copyright (c) 2010 Geoffry Song <goffrie@gmail.com>
- * Copyright (c) 2017 Scott Petrovic <scottpetrovic@gmail.com>
+ * SPDX-FileCopyrightText: 2008 Cyrille Berger <cberger@cberger.net>
+ * SPDX-FileCopyrightText: 2010 Geoffry Song <goffrie@gmail.com>
+ * SPDX-FileCopyrightText: 2017 Scott Petrovic <scottpetrovic@gmail.com>
  *
- *  This library is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU Lesser General Public License as published by
- *  the Free Software Foundation; version 2 of the License, or
- *  (at your option) any later version.
- *
- *  This library is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU Lesser General Public License for more details.
- *
- *  You should have received a copy of the GNU Lesser General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+ *  SPDX-License-Identifier: LGPL-2.0-or-later
  */
 
 #ifndef _PERSPECTIVE_ASSISTANT_H_
@@ -35,7 +23,7 @@ public:
     PerspectiveAssistant(QObject * parent = 0);
     KisPaintingAssistantSP clone(QMap<KisPaintingAssistantHandleSP, KisPaintingAssistantHandleSP> &handleMap) const override;
 
-    QPointF adjustPosition(const QPointF& point, const QPointF& strokeBegin) override;
+    QPointF adjustPosition(const QPointF& point, const QPointF& strokeBegin, const bool snapToAny) override;
     void setAdjustedBrushPosition(const QPointF position) override;
     void setFollowBrushPosition(bool follow) override;
     void endStroke() override;
@@ -47,9 +35,14 @@ public:
     bool contains(const QPointF& point) const override;
     qreal distance(const QPointF& point) const override;
 
+    int subdivisions() const;
+    void setSubdivisions(int subdivisions);
 
     bool isAssistantComplete() const override;
 
+    void saveCustomXml(QXmlStreamWriter *xml) override;
+    bool loadCustomXml(QXmlStreamReader *xml) override;
+
 protected:
     void drawCache(QPainter& gc, const KisCoordinatesConverter *converter,  bool assistantVisible=true) override;
 private:
@@ -60,13 +53,15 @@ private:
     bool getTransform(QPolygonF& polyOut, QTransform& transformOut) const;
     explicit PerspectiveAssistant(const PerspectiveAssistant &rhs, QMap<KisPaintingAssistantHandleSP, KisPaintingAssistantHandleSP> &handleMap);
 
+    // The number of subdivisions to draw
+    int m_subdivisions {8};
     // which direction to snap to (in transformed coordinates)
     QLineF m_snapLine;
     // cached information
     mutable QTransform m_cachedTransform;
     mutable QPolygonF m_cachedPolygon;
     mutable QPointF m_cachedPoints[4];
-    mutable bool m_cacheValid;
+    mutable bool m_cacheValid {false};
     // Needed to make sure that when we are in the middle of a brush stroke, the
     // guides follow the brush position, not the cursor position.
     bool m_followBrushPosition;
