@@ -1,21 +1,8 @@
 /*
- *  Copyright (c) 2005 Adrian Page <adrian@pagenet.plus.com>
- *  Copyright (c) 2010 Cyrille Berger <cberger@cberger.net>
+ *  SPDX-FileCopyrightText: 2005 Adrian Page <adrian@pagenet.plus.com>
+ *  SPDX-FileCopyrightText: 2010 Cyrille Berger <cberger@cberger.net>
  *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
- *  (at your option) any later version.
- *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
- *
- *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
+ *  SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #include "exr_converter.h"
@@ -24,6 +11,8 @@
 
 #include <ImfAttribute.h>
 #include <ImfChannelList.h>
+#include <ImfFrameBuffer.h>
+#include <ImfHeader.h>
 #include <ImfInputFile.h>
 #include <ImfOutputFile.h>
 
@@ -439,8 +428,8 @@ void EXRConverter::Private::decodeData1(Imf::InputFile& file, ExrPaintLayerInfo&
 
     QVector<pixel_type> pixels(width * height);
 
-    Q_ASSERT(info.channelMap.contains("G"));
-    dbgFile << "G -> " << info.channelMap["G"];
+    Q_ASSERT(info.channelMap.contains("Y"));
+    dbgFile << "Gray -> " << info.channelMap["Y"];
 
     bool hasAlpha = info.channelMap.contains("A");
     dbgFile << "Has Alpha:" << hasAlpha;
@@ -448,10 +437,9 @@ void EXRConverter::Private::decodeData1(Imf::InputFile& file, ExrPaintLayerInfo&
 
     Imf::FrameBuffer frameBuffer;
     pixel_type* frameBufferData = (pixels.data()) - xstart - ystart * width;
-    frameBuffer.insert(info.channelMap["G"].toLatin1().constData(),
-            Imf::Slice(ptype, (char *) &frameBufferData->gray,
-                       sizeof(pixel_type) * 1,
-                       sizeof(pixel_type) * width));
+    frameBuffer.insert(
+        info.channelMap["Y"].toLatin1().constData(),
+        Imf::Slice(ptype, (char *)&frameBufferData->gray, sizeof(pixel_type) * 1, sizeof(pixel_type) * width));
 
     if (hasAlpha) {
         frameBuffer.insert(info.channelMap["A"].toLatin1().constData(),
@@ -698,11 +686,11 @@ KisImportExportErrorCode EXRConverter::decode(const QString &filename)
             if (info.channelMap.size() == 1) {
                 modelId = GrayAColorModelID.id();
                 QString key = info.channelMap.begin().key();
-                if (key != "G") {
-                    info.remappedChannels.push_back(ExrPaintLayerInfo::Remap(key, "G"));
+                if (key != "Y") {
+                    info.remappedChannels.push_back(ExrPaintLayerInfo::Remap(key, "Y"));
                     QString channel =  info.channelMap.begin().value();
                     info.channelMap.clear();
-                    info.channelMap["G"] = channel;
+                    info.channelMap["Y"] = channel;
                 }
             }
             else if (info.channelMap.size() == 2) {
@@ -714,19 +702,18 @@ KisImportExportErrorCode EXRConverter::decode(const QString &filename)
                 QString failingChannelKey;
 
                 for (; it != end; ++it) {
-                    if (it.key() != "G" && it.key() != "A") {
+                    // BUG: 461975
+                    if (it.key() != "A") {
                         failingChannelKey = it.key();
                         break;
                     }
                 }
 
-                info.remappedChannels.push_back(
-                            ExrPaintLayerInfo::Remap(failingChannelKey, "G"));
+                info.remappedChannels.push_back(ExrPaintLayerInfo::Remap(failingChannelKey, "Y"));
 
                 QString failingChannelValue = info.channelMap[failingChannelKey];
                 info.channelMap.remove(failingChannelKey);
-                info.channelMap["G"] = failingChannelValue;
-
+                info.channelMap["Y"] = failingChannelValue;
             }
             else if (info.channelMap.size() == 3 || info.channelMap.size() == 4) {
 
@@ -785,7 +772,7 @@ KisImportExportErrorCode EXRConverter::decode(const QString &filename)
         const KoColorSpace* colorSpace = kisTypeToColorSpace(RGBAColorModelID.id(), imageType);
 
         if (!colorSpace) return ImportExportCodes::FormatColorSpaceUnsupported;
-        dbgFile << "Colorspace: " << colorSpace->name();
+        dbgFile << "Color space: " << colorSpace->name();
 
         // Set the colorspace on all groups
         for (int i = 0; i < groups.size(); ++i) {
@@ -900,7 +887,7 @@ KisImportExportErrorCode EXRConverter::decode(const QString &filename)
                           "<br/><br/>"
                           "This will hardly make any visual difference just keep it in mind.");
             if (d->showNotifications) {
-                QMessageBox::information(0, i18nc("@title:window", "EXR image has been modified"), msg);
+                QMessageBox::information(qApp->activeWindow(), i18nc("@title:window", "EXR image has been modified"), msg);
             } else {
                 warnKrita << "WARNING:" << msg;
             }
@@ -1116,17 +1103,37 @@ KisImportExportErrorCode EXRConverter::buildFile(const QString &filename, KisPai
     else if (info.layerDevice->colorSpace()->colorDepthId() == Float32BitsColorDepthID) {
         pixelType = Imf::FLOAT;
     }
-    header.channels().insert("R", Imf::Channel(pixelType));
-    header.channels().insert("G", Imf::Channel(pixelType));
-    header.channels().insert("B", Imf::Channel(pixelType));
-    header.channels().insert("A", Imf::Channel(pixelType));
 
-    info.channels.push_back("R");
-    info.channels.push_back("G");
-    info.channels.push_back("B");
-    info.channels.push_back("A");
     info.pixelType = pixelType;
 
+    if (info.layerDevice->colorSpace()->colorModelId() == RGBAColorModelID) {
+        header.channels().insert("R", Imf::Channel(pixelType));
+        header.channels().insert("G", Imf::Channel(pixelType));
+        header.channels().insert("B", Imf::Channel(pixelType));
+        header.channels().insert("A", Imf::Channel(pixelType));
+
+        info.channels.push_back("R");
+        info.channels.push_back("G");
+        info.channels.push_back("B");
+        info.channels.push_back("A");
+    } else if (info.layerDevice->colorSpace()->colorModelId() == GrayAColorModelID) {
+        header.channels().insert("Y", Imf::Channel(pixelType));
+        header.channels().insert("A", Imf::Channel(pixelType));
+
+        info.channels.push_back("Y");
+        info.channels.push_back("A");
+    } else if (info.layerDevice->colorSpace()->colorModelId() == XYZAColorModelID) {
+        header.channels().insert("X", Imf::Channel(pixelType));
+        header.channels().insert("Y", Imf::Channel(pixelType));
+        header.channels().insert("Z", Imf::Channel(pixelType));
+        header.channels().insert("A", Imf::Channel(pixelType));
+
+        info.channels.push_back("X");
+        info.channels.push_back("Y");
+        info.channels.push_back("Z");
+        info.channels.push_back("A");
+    }
+
     // Open file for writing
     try {
         Imf::OutputFile file(filename.toUtf8(), header);
@@ -1241,19 +1248,14 @@ void EXRConverter::Private::recBuildPaintLayerSaveInfo(QList<ExrPaintLayerSaveIn
                     info.channels.push_back(info.name + remap(current2original, "A"));
                 }
                 else if (info.layerDevice->colorSpace()->colorModelId() == GrayAColorModelID) {
-                    info.channels.push_back(info.name + remap(current2original, "G"));
+                    info.channels.push_back(info.name + remap(current2original, "Y"));
                     info.channels.push_back(info.name + remap(current2original, "A"));
-                }
-                else if (info.layerDevice->colorSpace()->colorModelId() == GrayColorModelID) {
-                    info.channels.push_back(info.name + remap(current2original, "G"));
-                }
-                else if (info.layerDevice->colorSpace()->colorModelId() == XYZAColorModelID) {
+                } else if (info.layerDevice->colorSpace()->colorModelId() == XYZAColorModelID) {
                     info.channels.push_back(info.name + remap(current2original, "X"));
                     info.channels.push_back(info.name + remap(current2original, "Y"));
                     info.channels.push_back(info.name + remap(current2original, "Z"));
                     info.channels.push_back(info.name + remap(current2original, "A"));
                 }
-
             }
 
             if (info.layerDevice->colorSpace()->colorDepthId() == Float16BitsColorDepthID) {
