@@ -1,19 +1,7 @@
 /*
- *  Copyright (c) 2012 Dmitry Kazakov <dimula73@gmail.com>
+ *  SPDX-FileCopyrightText: 2012 Dmitry Kazakov <dimula73@gmail.com>
  *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
- *  (at your option) any later version.
- *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
- *
- *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+ *  SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #ifndef __KIS_DAB_CACHE_H
@@ -76,6 +64,14 @@ public:
                                    QRect *dstDabRect,
                                    qreal lightnessStrength = 1.0);
 
+    KisFixedPaintDeviceSP fetchNormalizedImageDab(const KoColorSpace *cs,
+                                                  const QPointF &cursorPoint,
+                                                  KisDabShape const& shape,
+                                                  const KisPaintInformation& info,
+                                                  qreal softnessFactor,
+                                                  QRect *dstDabRect);
+
+
     void setSharpnessPostprocessing(KisPressureSharpnessOption *option);
     void setTexturePostprocessing(KisTextureProperties *option);
 
@@ -94,7 +90,8 @@ private:
             const KisPaintInformation& info,
             qreal softnessFactor,
             QRect *dstDabRect,
-            qreal lightnessStrength = 1.0);
+            qreal lightnessStrength = 1.0,
+            bool forceNormalizedRGBAImageStamp = false);
 
 private:
 
