@@ -1,19 +1,7 @@
 /*
- *  Copyright (c) 2016 Dmitry Kazakov <dimula73@gmail.com>
+ *  SPDX-FileCopyrightText: 2016 Dmitry Kazakov <dimula73@gmail.com>
  *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
- *  (at your option) any later version.
- *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
- *
- *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+ *  SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #include "kis_roundmarkerop.h"
@@ -34,7 +22,7 @@
 #include <kis_image.h>
 #include <kis_selection.h>
 #include <kis_brush_based_paintop_settings.h>
-#include <kis_cross_device_color_picker.h>
+#include <kis_cross_device_color_sampler.h>
 #include <kis_fixed_paint_device.h>
 #include <kis_lod_transform.h>
 #include <kis_spacing_information.h>
@@ -83,9 +71,11 @@ KisSpacingInformation KisRoundMarkerOp::paintAt(const KisPaintInformation& info)
     if (KisPaintOpUtils::checkSizeTooSmall(scale, diameter, diameter)) return KisSpacingInformation();
     KisDabShape shape(scale, 1.0, rotation);
 
-    // Subtracting .5 from both dimensions, because the final dab tends to exagerate towards the lower right.
-    // This aligns it with the brush cursor.
-    QPointF pos = info.pos() - QPointF(0.5, 0.5);
+    // The position will need subtracting 0.5, but you cannot do this here
+    // because then the mirroring tools get wrong position to mirror
+    // and the mirroring doesn't work well.
+    // Subtracting must happen just before the painting.
+    QPointF pos = info.pos();
 
     KisMarkerPainter gc(painter()->device(), painter()->paintColor());
 
@@ -94,15 +84,19 @@ KisSpacingInformation KisRoundMarkerOp::paintAt(const KisPaintInformation& info)
             painter()->calculateAllMirroredPoints(pos);
 
         Q_FOREACH(const QPointF &pt, points) {
-            gc.fillFullCircle(pt, radius);
+            // Subtracting .5 from both dimensions, because the final dab tends to exaggerate towards the lower right.
+            // This aligns it with the brush cursor.
+            gc.fillFullCircle(pt - QPointF(0.5, 0.5), radius);
         }
     } else {
         const QVector<QPair<QPointF, QPointF>> pairs =
             painter()->calculateAllMirroredPoints(qMakePair(m_lastPaintPos, pos));
 
         Q_FOREACH(const auto &pair, pairs) {
-            gc.fillCirclesDiff(pair.first, m_lastRadius,
-                               pair.second, radius);
+            // Subtracting .5 from both dimensions, because the final dab tends to exaggerate towards the lower right.
+            // This aligns it with the brush cursor.
+            gc.fillCirclesDiff(pair.first - QPointF(0.5, 0.5), m_lastRadius,
+                               pair.second - QPointF(0.5, 0.5), radius);
         }
     }
 
