@@ -53,10 +53,10 @@ class ImageView
 {
 
 protected:
-    quint8* m_data;
-    int m_imageWidth;
-    int m_imageHeight;
-    int m_pixelSize;
+    quint8* m_data {nullptr};
+    int m_imageWidth {0};
+    int m_imageHeight {0};
+    int m_pixelSize {0};
 
 public:
     void Init(quint8* _data, int _imageWidth, int _imageHeight, int _pixelSize)
@@ -203,10 +203,10 @@ private:
     template <typename T> friend float distance_impl(const MaskedImage& my, int x, int y, const MaskedImage& other, int xo, int yo);
 
     QRect imageSize;
-    int nChannels;
+    int nChannels {0};
 
-    const KoColorSpace* cs;
-    const KoColorSpace* csMask;
+    const KoColorSpace* cs {nullptr};
+    const KoColorSpace* csMask {nullptr};
 
     ImageData maskData;
     ImageData imageData;
@@ -492,7 +492,7 @@ template <typename T> float distance_impl(const MaskedImage& my, int x, int y, c
     }
 
     // in HDR color spaces the value of the cnannel may become bigger than the unitValue
-    return qMin(1.0f, dsq / (pow2((float)KoColorSpaceMathsTraits<T>::unitValue) / MAX_DIST ));
+    return qMin((float)(nchannels * MAX_DIST), dsq / (pow2((float)KoColorSpaceMathsTraits<T>::unitValue) / MAX_DIST ));
 }
 
 
