@@ -1,19 +1,7 @@
 /*
- *  Copyright (c) 2014 Dmitry Kazakov <dimula73@gmail.com>
+ *  SPDX-FileCopyrightText: 2014 Dmitry Kazakov <dimula73@gmail.com>
  *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
- *  (at your option) any later version.
- *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
- *
- *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+ *  SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #include "kis_warp_transform_strategy.h"
@@ -46,13 +34,6 @@ struct KisWarpTransformStrategy::Private
           converter(_converter),
           currentArgs(_currentArgs),
           transaction(_transaction),
-          lastNumPoints(0),
-          drawConnectionLines(false), // useful while developing
-          drawOrigPoints(false),
-          drawTransfPoints(true),
-          closeOnStartPointClick(false),
-          clipOriginalPointsPosition(true),
-          pointWasDragged(false),
           recalculateSignalCompressor(40, KisSignalCompressor::FIRST_ACTIVE)
     {
     }
@@ -61,7 +42,7 @@ struct KisWarpTransformStrategy::Private
 
     /// standard members ///
 
-    const KisCoordinatesConverter *converter;
+    const KisCoordinatesConverter *converter {0};
 
     //////
     ToolTransformArgs &currentArgs;
@@ -77,7 +58,7 @@ struct KisWarpTransformStrategy::Private
 
     QImage transformedImage;
 
-    int pointIndexUnderCursor;
+    int pointIndexUnderCursor {0};
 
     enum Mode {
         OVER_POINT = 0,
@@ -90,15 +71,15 @@ struct KisWarpTransformStrategy::Private
     Mode mode;
 
     QVector<int> pointsInAction;
-    int lastNumPoints;
+    int lastNumPoints {0};
 
-    bool drawConnectionLines;
-    bool drawOrigPoints;
-    bool drawTransfPoints;
-    bool closeOnStartPointClick;
-    bool clipOriginalPointsPosition;
+    bool drawConnectionLines {false}; // useful while developing
+    bool drawOrigPoints {false};
+    bool drawTransfPoints {true};
+    bool closeOnStartPointClick {false};
+    bool clipOriginalPointsPosition {true};
     QPointF pointPosOnClick;
-    bool pointWasDragged;
+    bool pointWasDragged {false};
 
     QPointF lastMousePos;
 
@@ -114,9 +95,10 @@ struct KisWarpTransformStrategy::Private
 };
 
 KisWarpTransformStrategy::KisWarpTransformStrategy(const KisCoordinatesConverter *converter,
+                                                   KoSnapGuide *snapGuide,
                                                    ToolTransformArgs &currentArgs,
                                                    TransformTransactionProperties &transaction)
-    : KisSimplifiedActionPolicyStrategy(converter),
+    : KisSimplifiedActionPolicyStrategy(converter, snapGuide),
       m_d(new Private(this, converter, currentArgs, transaction))
 {
     connect(&m_d->recalculateSignalCompressor, SIGNAL(timeout()),
@@ -631,6 +613,7 @@ void KisWarpTransformStrategy::Private::recalculateTransformations()
 
     handlesTransform = scaleTransform;
     emit q->requestCanvasUpdate();
+    emit q->requestImageRecalculation();
 }
 
 QImage KisWarpTransformStrategy::calculateTransformedImage(ToolTransformArgs &currentArgs,
